==> haskell-tasty-lua-1.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-lua
version:              1.0.2
visibility:           public
id:                   tasty-lua-1.0.2-y85Cx0j1CACRJCvWLOhJG
key:                  tasty-lua-1.0.2-y85Cx0j1CACRJCvWLOhJG
license:              MIT
copyright:            © 2019–2022 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  c151802ce3fbd65ea4020dba099b5d71
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-lua-1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-lua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.0.2-y85Cx0j1CACRJCvWLOhJG
depends:
    QuickCheck-2.14.2-JAfVoSJ1VKW3z92cRcZSMa base-4.15.1.0
    bytestring-0.10.12.1 file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn
    hslua-core-2.2.0-90sOWLUKsuCGTRkW5Ioq7Q
    hslua-marshalling-2.2.0-YYyKMEJcfZ56v1se3gqah
    lua-arbitrary-1.0.1-1mvbwia6wVm8rzQGLBeEn8
    tasty-1.4.2.2-BSfDzL4QGsxAyZbz6zTcM text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-1.0.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-lua
version:              1.0.2
visibility:           public
id:                   tasty-lua-1.0.2-CBYJiBXH9veJ6T52rIe0SR
key:                  tasty-lua-1.0.2-CBYJiBXH9veJ6T52rIe0SR
license:              MIT
copyright:            © 2019–2022 Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  6050e64cc4b7091adf5e5b3cb04716ce
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-lua-1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-lua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.0.2-CBYJiBXH9veJ6T52rIe0SR
depends:
    QuickCheck-2.14.2-50g6nvTiNE5CM6werdwjjj base-4.15.1.0
    bytestring-0.10.12.1 file-embed-0.0.15.0-FF5xUPWKaB3GI64c6hgPnn
    hslua-core-2.2.1-JqkyE3iCsxd5i7u9s4tWgb
    hslua-marshalling-2.2.1-D1n9Rpi3R4cJF3f3bqray5
    lua-arbitrary-1.0.1-H1shwCGsV51ENuSO6uSzw
    tasty-1.4.2.3-LfCoZZg5ttU5VpHV083ruq text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
